pub struct CoreInitOptions {
pub gateway_opts: ServerGatewayOptions,
pub evict_after_pending_cleared: bool,
pub max_outstanding_workflow_tasks: usize,
pub max_outstanding_activities: usize,
}Expand description
Holds various configuration information required to call init
Fields
gateway_opts: ServerGatewayOptionsOptions for the connection to the temporal server
evict_after_pending_cleared: boolIf set to true (which should be the default choice until sticky task queues are implemented) workflows are evicted after they no longer have any pending activations. IE: After they have sent new commands to the server.
max_outstanding_workflow_tasks: usizeThe maximum allowed number of workflow tasks that will ever be given to lang at one time. Note that one workflow task may require multiple activations - so the WFT counts as “outstanding” until all activations it requires have been completed.
max_outstanding_activities: usizeThe maximum allowed number of activity tasks that will ever be given to lang at one time.